package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````$"D```````!``````````&C!````
M`````````$``.``.`$``'@`=``8````$````0`````````!``````````$``
M````````$`,````````0`P````````@``````````P````0```#$`P``````
M`,0#````````Q`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````.@5````````Z!4`````````
M$`````````$````%`````"``````````(``````````@````````/4(`````
M```]0@`````````0`````````0````0`````<`````````!P`````````'``
M``````#(1P```````,A'`````````!`````````!````!@```,"[````````
MP,L```````#`RP```````&@$````````V`0`````````$`````````(````&
M````\+L```````#PRP```````/#+``````````(``````````@````````@`
M````````!`````0```!0`P```````%`#````````4`,```````!0````````
M`%``````````"``````````$````!````*`#````````H`,```````"@`P``
M`````"0`````````)``````````$``````````0````$````J+<```````"H
MMP```````*BW````````(``````````@``````````0`````````4^5T9`0`
M``!0`P```````%`#````````4`,```````!0`````````%``````````"```
M``````!0Y71D!````+"P````````L+````````"PL`````````0!````````
M!`$````````$`````````%'E=&0&````````````````````````````````
M`````````````````````````!``````````4N5T9`0```#`NP```````,#+
M````````P,L```````!`!````````$`$`````````0`````````$````0```
M``4```!'3E4``@``P`0````#``````````*``,`$`````0`````````!``'`
M!`````D``````````@`!P`0````!``````````0````4`````P```$=.50"L
MGG82CU)?]6"%]@XH$-E@\17UJR]L:6(V-"]L9"UL:6YU>"UX.#8M-C0N<V\N
M,@`(````/P````$````&````$`F!`,`!0`(_````0`````````!!````0@``
M``````!#`````````-%ESFTY\HL<"XH05\6YG$"GW:-K````````````````
M`````````````````````'$````2`````````````````````````'L````2
M`````````````````````````'L!```2`````````````````````````'L"
M```2`````````````````````````$P"```2````````````````````````
M`(<````2``````````````````````````$````@````````````````````
M`````)<!```2`````````````````````````-\"```2````````````````
M`````````/$!```2`````````````````````````,T"```2````````````
M`````````````"`!```2`````````````````````````+D````2````````
M`````````````````&$````2`````````````````````````,T!```2````
M`````````````````````.L!```2`````````````````````````.<````2
M`````````````````````````/8!```2`````````````````````````!@"
M```2`````````````````````````-L!```2````````````````````````
M`!`````@`````````````````````````-P````2````````````````````
M`````'8````2`````````````````````````.0!```2````````````````
M`````````"P````@`````````````````````````%L"```2````````````
M`````````````)@"```2``````````````````````````D"```2````````
M`````````````````%,````2`````````````````````````"<!```6````
M``````````````````````0!```2`````````````````````````%L!```2
M`````````````````````````*@````2`````````````````````````/4`
M```2`````````````````````````,4!```2````````````````````````
M`+X!```2`````````````````````````,T````2````````````````````
M`````!\"```2`````````````````````````)$"```2````````````````
M`````````)H````2`````````````````````````+P"```2````````````
M`````````````*X!```2`````````````````````````$\!```2````````
M`````````````````(8!```2`````````````````````````+4"```2````
M`````````````````````-0!```2`````````````````````````%H"```2
M`````````````````````````*`"```2`````````````````````````#H!
M```2`````````````````````````!0!```2````````````````````````
M`)P!```2`````````````````````````+4!```2````````````````````
M`````#`"```2`````````````````````````*<"```2````````````````
M`````````"@"```2`````````````````````````,(````2````````````
M`````````````#X"```2`````````````````````````&P!```2````````
M`````````````````&("```2`````````````````````````*X"```2````
M`````````````````````*0!```2``````````````````````````,"```2
M`````````````````````````(("```B`````````````````````````'0"
M```1`!L`8-`````````(`````````$8````1`!L`<-`````````!````````
M`-4"```1`!L`0-`````````(`````````-<"```A`!L`0-`````````(````
M``````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!03%]D;U]U;F1U;7``4&5R
M;%]S>7-?=&5R;0!097)L7V=V7V9E=&-H<'8`<&5R;%]F<F5E`%!E<FQ?9V5T
M7W-V`%!E<FQ?871F;W)K7W5N;&]C:P!P97)L7V1E<W1R=6-T`%!E<FQ?;F5W
M6%-?9FQA9W,`<&5R;%]R=6X`4&5R;%]N97=84P!097)L7W-V7W-E='!V;@!P
M97)L7V%L;&]C`%!E<FQ?<W9?<V5T<'8`<&5R;%]C;VYS=')U8W0`8F]O=%]$
M>6YA3&]A9&5R`%!E<FQ?<V%F97-Y<VUA;&QO8P!03%]C=7)R96YT7V-O;G1E
M>'0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?;&]C:P!097)L7W-Y<U]I;FET,P!P97)L7W!A<G-E`%]?<W1A8VM?8VAK
M7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`
M;W!E;C8T`'-T<G)C:'(`=6YL:6YK`'-T<G1O:P!G971P=W5I9`!S=')L96X`
M<FUD:7(`<F5A9`!?7VUE;6-P>5]C:&L`;6MD:7(`7U]V9G!R:6YT9E]C:&L`
M9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7VUE;6UO
M=F5?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I
M;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!O<&5N9&ER
M`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N
M`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN
M<V\N-2XT,`!L:6)C+G-O+C8`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,T`$=,24)#
M7S(N-`!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,RXT`$=,24)#
M7S(N,BXU`````0`!``$``@`#``$``0`"``0``@`"``(``0`!``(``@`!``,`
M`@`"``$``0`"``(``0`%``(``P`!``$``0`!``$``0`"``(``0`"``(``0`"
M``(``0`&``(``@`%``(``0`!``(``@`#``(``@`!``,``0`'``@``@`"``(`
M`@`!``(``@`````````!``<``0,``!``````````E)&6!@``"``+`P``$```
M`+21E@8```<`%@,``!`````4:6D-```&`"$#```0````LY&6!@``!0`K`P``
M$````'(9:0D```0`-@,``!````!T&6D)```#`$(#```0````=1II"0```@!.
M`P```````,#+````````"`````````#P*0```````,C+````````"```````
M``"P*0```````-#+````````"`````````!.<0```````-C+````````"```
M``````#I<````````.#+````````"``````````&<0```````.C+````````
M"`````````!?<0````````C0````````"``````````(T````````"#0````
M````"`````````#X<@```````+C/````````!@````8``````````````,#/
M````````!@````<``````````````,C/````````!@```!4`````````````
M`-#/````````!@```!D``````````````-C/````````!@```#\`````````
M`````.#/````````$@```!X``````````````.C/````````!@```!\`````
M`````````/#/````````!@```"```````````````/C/````````!@```#L`
M`````````````$#0````````!0```$(``````````````&#0````````!0``
M`$```````````````'#0````````!0```$$```````````````C.````````
M!P````$``````````````!#.````````!P````(``````````````!C.````
M````!P````,``````````````"#.````````!P````0``````````````"C.
M````````!P````4``````````````##.````````!P````@`````````````
M`#C.````````!P````D``````````````$#.````````!P````H`````````
M`````$C.````````!P````L``````````````%#.````````!P````P`````
M`````````%C.````````!P````T``````````````&#.````````!P````X`
M`````````````&C.````````!P````\``````````````'#.````````!P``
M`!```````````````'C.````````!P```!$``````````````(#.````````
M!P```!(``````````````(C.````````!P```!,``````````````)#.````
M````!P```!0``````````````)C.````````!P```!8``````````````*#.
M````````!P```!<``````````````*C.````````!P```!@`````````````
M`+#.````````!P```!H``````````````+C.````````!P```!L`````````
M`````,#.````````!P```!P``````````````,C.````````!P```!T`````
M`````````-#.````````!P```"$``````````````-C.````````!P```"(`
M`````````````.#.````````!P```",``````````````.C.````````!P``
M`"0``````````````/#.````````!P```"4``````````````/C.````````
M!P```"8```````````````#/````````!P```"<```````````````C/````
M````!P```"@``````````````!#/````````!P```"D``````````````!C/
M````````!P```"H``````````````"#/````````!P```"L`````````````
M`"C/````````!P```"P``````````````##/````````!P```"T`````````
M`````#C/````````!P```"X``````````````$#/````````!P```"\`````
M`````````$C/````````!P```#```````````````%#/````````!P```#$`
M`````````````%C/````````!P```#(``````````````&#/````````!P``
M`#,``````````````&C/````````!P```#0``````````````'#/````````
M!P```#4``````````````'C/````````!P```#8``````````````(#/````
M````!P```#<``````````````(C/````````!P```#@``````````````)#/
M````````!P```#D``````````````)C/````````!P```#H`````````````
M`*#/````````!P```#P``````````````*C/````````!P```#T`````````
M`````+#/````````!P```#X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;&O``!(A<!T`O_02(/$",,``````/\UTJT``/\EU*T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OIH-0```.F2_/__9I#S#Q[Z_R4^K```9@\?1```\P\>^O\E7JH``&8/'T0`
M`/,/'OK_)5:J``!F#Q]$``#S#Q[Z_R5.J@``9@\?1```\P\>^O\E1JH``&8/
M'T0``/,/'OK_)3ZJ``!F#Q]$``#S#Q[Z_R4VJ@``9@\?1```\P\>^O\E+JH`
M`&8/'T0``/,/'OK_)2:J``!F#Q]$``#S#Q[Z_R4>J@``9@\?1```\P\>^O\E
M%JH``&8/'T0``/,/'OK_)0ZJ``!F#Q]$``#S#Q[Z_R4&J@``9@\?1```\P\>
M^O\E_JD``&8/'T0``/,/'OK_)?:I``!F#Q]$``#S#Q[Z_R7NJ0``9@\?1```
M\P\>^O\EYJD``&8/'T0``/,/'OK_)=ZI``!F#Q]$``#S#Q[Z_R76J0``9@\?
M1```\P\>^O\ESJD``&8/'T0``/,/'OK_)<:I``!F#Q]$``#S#Q[Z_R6^J0``
M9@\?1```\P\>^O\EMJD``&8/'T0``/,/'OK_):ZI``!F#Q]$``#S#Q[Z_R6F
MJ0``9@\?1```\P\>^O\EGJD``&8/'T0``/,/'OK_)9:I``!F#Q]$``#S#Q[Z
M_R6.J0``9@\?1```\P\>^O\EAJD``&8/'T0``/,/'OK_)7ZI``!F#Q]$``#S
M#Q[Z_R5VJ0``9@\?1```\P\>^O\E;JD``&8/'T0``/,/'OK_)6:I``!F#Q]$
M``#S#Q[Z_R5>J0``9@\?1```\P\>^O\E5JD``&8/'T0``/,/'OK_)4ZI``!F
M#Q]$``#S#Q[Z_R5&J0``9@\?1```\P\>^O\E/JD``&8/'T0``/,/'OK_)3:I
M``!F#Q]$``#S#Q[Z_R4NJ0``9@\?1```\P\>^O\E)JD``&8/'T0``/,/'OK_
M)1ZI``!F#Q]$``#S#Q[Z_R46J0``9@\?1```\P\>^O\E#JD``&8/'T0``/,/
M'OK_)0:I``!F#Q]$``#S#Q[Z_R7^J```9@\?1```\P\>^O\E]J@``&8/'T0`
M`/,/'OK_)>ZH``!F#Q]$``#S#Q[Z_R7FJ```9@\?1```\P\>^O\EWJ@``&8/
M'T0``/,/'OK_)=:H``!F#Q]$``#S#Q[Z_R7.J```9@\?1```\P\>^O\EQJ@`
M`&8/'T0``/,/'OK_);ZH``!F#Q]$``#S#Q[Z_R6VJ```9@\?1```\P\>^E53
M2(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"&1(BQ0E*````$B)5"0H2(U4
M)`CHAO___TB+-7>H``!(BSVHJ```2(GRZ-`Z``"`/1FI````#X0:`0``2(L%
M?*@``&1(BP"`B#H$```#BT0D'(UX!(U8`TAC_TC!YP/HN_[__TB+3"001(M$
M)!Q(B<=(B07OJ```2(L!2(D'2(T%04H``$B)1PA(BP5OJ```2(E'$$B-!2Y*
M``!(B4<808/X`0^.*@$``$B#P0A!@\`#N`0```!F#Q^$``````!(BS%(8]"#
MP`%(@\$(2(DTUT0YP'7J2)A(B?E%,<")VDC'!,<`````2(L]@:@``$B--?H'
M``#HI?O__X7`#X2$````2(L]9J@``.AQ_?__2(UT)"1(C3UH2```B<4QP.B\
M`0``2(7`=&](BSU`J```Z$O[___HQOS__TB+1"0H9$@K!"4H````#X6:````
M2(/$.(GH6UW#Z$3\__](B04-J```2(7`='9(B<?HL/S__TB+!4FG``!D2(L0
MQH*V"````.F]_O__2(L]XJ<``.B-^___Z6O___](BSW!IP``2(7_=`KHIQT`
M`.E[____2(T]@T<``$B-="0DZ"$!``!(B06:IP``2(G'2(7`#X17____Z]"X
M!````.GX_O__OP$```#HZ/K__^C3_/__#Q\`\P\>^C'M28G17DB)XDB#Y/!0
M5$4QP#')2(T]T?W___\5PZ8``/1F+@\?A```````2(T]X:8``$B-!=JF``!(
M.?AT%4B+!6ZF``!(A<!T"?_@#Q^``````,,/'X``````2(T]L:8``$B--:JF
M``!(*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%-:8``$B%P'0(_^!F#Q]$``##
M#Q^``````/,/'OJ`/;:F````=2M52(,]$J8```!(B>5T#$B+/3:F``#HN?G_
M_^AD____Q@6.I@```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=!
M5D%505154TB#[`A,BRTKI@``387M#X2C````#[8'A,!T!#P]=6=%,>1)BUT`
M2(7;=$%)B?=)B?Y-8^1,B>UF9BX/'X0```````\?0`!,B>),B?9(B=_HPOG_
M_X7`=0="@#PC/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?
MA```````28G\00^V1"0!28/$`83`=`0\/77N02G\ZX)F#Q]$``!,*>U*C5PC
M`4C!_0-!B2_KM3';Z[%F9BX/'X0``````%-(@>R@````9$B+'"4H````2(F<
M))@```!(B?M(B>;H'/O__X7`=3B+5"08@>(`\```@?H`0```=`B!^@"@``!U
M(+X"````2(G?Z&'[__^%P`^4P`^VP.L)#Q^``````#'`2(N4))@```!D2"L4
M)2@```!U"4B!Q*````!;P^B-^O__9F8N#Q^$``````!FD$%655-(@>RP````
M9$B+!"4H````2(F$)*@````QP$B%_W0(2(G[@#\`=25(BX0DJ````&1(*P0E
M*`````^%+0$``$B!Q+````!;74%>PV:0Z$OY__](B<5(A<!TSDB)[^@;^___
M2(7`#X3"````3(U($X!X$RYU"$&`>0$`=-Z0@'@3+@^$O@```$B)WTR)#"3H
MZOC__TR+#"1)B<9,B<],B4PD".C6^/__08U4!@)(8])(B==(B10DZ!+X__],
MBTPD"$B+%"1)B=A)B<9(B<>^`@```#'`2(T-QD,``.@M^O__3(GW2(UT)!#H
MH/C__TR)]X/X_W00BT0D*"4`\```/0!```!T8.CS]___3(GWZ%OX__](B>_H
M8_K__TB%P`^%2/___V8N#Q^$``````!(B>_HR/G__TB)W^C0]___Z>;^__\/
M'P!!@'D!+@^%-____T&`>0(`#X3__O__Z2?___\/'T0``.B3_O__ZY[H#/G_
M_V9F+@\?A```````D$%6,<!!54%455-(@^P@@#X]9$B+'"4H````2(E<)!A(
MB?L/E,!(C2P&2(GOZ,_W__](C70D%$F)Q#'`2(G?Z-W\__](A<`/A`P!``!(
MB<=)B<7HJ??__TPYX`^#V````$QC;"042<'E`P^V`X3`#X2\`0``/#T/A+0!
M``!(B=B0#[90`4B#P`&$TG0%@/H]=>](*=A(F$R+-<.B``!*C7P@`NBI]O__
M30'N28D&2(7`=%](BP6GH@``2HL4*`^V`X@"/#UT,(3`="Q(C4,!ZQ5F9BX/
M'X0```````\?1```@/D]=!$/M@A(@\(!2(/``8@*A,EUZL8"/3'`#Q]$```/
MMDP%`(A,`@%(@\`!A,EU[TB+1"089$@K!"4H````#X4?`0``2(/$(%M=05Q!
M74%>PV8/'T0``#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[T/'T``3(L-
M`:(``$F#.0`/A,X```!,B<A%,?9F9BX/'X0``````&8/'T0``$B#P`A$B?)!
M@\8!2(,X`'7OC4H#2&/)2,'A`XL%]Z$``(7`=6-(B<],B4PD",<%X:$```$`
M``!(B0PDZ)#U__](B<=(A<`/A$7___]-8^Y(BPPD2(MT)`A)P>4#3(GJZ.SW
M__](B05UH0``2(G'18U&`4UCP$K'!,<`````Z6?^__]F#Q]$``!,B<](B<[H
MG??__TB)!4:A``!(B<=(A<`/A.O^__]-8^Y)P>4#Z[^0,<#I7_[__[D0````
M13'VZ5?____HM_;__P\?@`````!!5%532('L`!```$B##"0`2(/L(+K_#P``
M9$R+)"4H````3(FD)!@0``!)B?1(B?U(C70D$$B-/9Y```#H#_;__X7`?A1(
M8\B#Z`%(8]"`?!00`'5+A<!U-4B+!5"@``!,B>)(B>YD2(LXZ.'T__](BX0D
M&!```&1(*P0E*````'592('$(!```%M=05S#2&/(9F8N#Q^$```````/'T``
M2(G*OB\```!(C7PD$$B)3"0(Z.GS__](A<!TG4B+!>V?``!(BTPD"$B-5"00
M2(GN9$B+..AG]?__ZY3HT/7___,/'OI32(L=Q)\``$B-#4V```!(C37O/P``
M2(L5MY\``&1(BSOH9O;__V1(BSM%,<E;3(T%>T$``$B-%0`4``!,B<%(C37;
M/P``Z='T__^0\P\>^DB+!76?``!(BQ5VGP``2(T-]W\``$B--9D_``!D2(LX
MZ1?V__\/'X``````\P\>^E532('L`!```$B##"0`2('L`!```$B##"0`2(/L
M.&1(BP0E*````$B)A"0H(```,<!(C:PD(!```.C.\___N@$0``"^`@```$R-
M#3(_``!!B<!(C0U=/P``2(U\)!`QP.AW]?__2(U\)!"Z`!```$B)[NAU]/__
M,?^%P'@XC4@!2(G#2&/)2(G/2(E,)`CH"?/__TB)QTB%P'0:2&/;2(M,)`A(
MB>Y(B=KH3O/__\8$&`!(B<=(BX0D*"```&1(*P0E*````'4-2('$."```$B)
M^%M=P^AR]/__9I#S#Q[ZZ1?___\/'X``````\P\>^D%7059!54%455-(@>P`
M$```2(,,)`!(@>RX````9$B+!"4H````2(F$)*@0```QP$F)_$B)\TB-/9<^
M``!(C70D#.@U^/__OB\```!,B>=(B<7HM?/__TB%P'1`,<!,B>9(C3UU/@``
MZ._Z__],B>!(BY0DJ!```&1(*Q0E*`````^%D@$``$B!Q+@0``!;74%<05U!
M7D%?PP\?`$B)W^B8\___2(TU/SX``$B)Q^C)\___2(G#2(7`=*%,C:PDH```
M`$R-="00@#L`#X3O````9F8N#Q^$``````!(A>UT$TB)WDB)[^B`\___A<`/
MA*D```!(B=_H8/+__TB-5`/_28G'2#G3<A_K+69F+@\?A```````9@\?1```
MQ@(`2(/J`4@YTW0%@#HO=.](B=_H)_+__TF)QTR)Y^@<\O__28U$!P%(/?\/
M```/APO___](@^P(2(T-E#X``$F)V#'`052Z`!```+X"````3(GO3(T-=3T`
M`.AP\___3(GV3(GOZ.7Q__]:687`=1"+1"0H)0#P```]`(```'1/2(TU1CT`
M`#'_Z-'R__](B<-(A<`/A*7^__^`.P`/A1S___](A>UT!H!]`"YT&4&_`0``
M`$B-'?H\``#I6____P\?@`````"`?0$`=+/KW[X!````3(GOZ`/S__^%P'6@
M3(GN2(T]UCP``.A0^?__3(GOZ"CR___I5_[__^@^\O__9F8N#Q^$```````/
M'P#S#Q[Z4[XO````2(G[Z([Q__](C7@!2(7`2`]$^UOI[?'__V9F+@\?A```
M````9I#S#Q[Z2('L`!```$B##"0`2(/L*&1(BP0E*````$B)A"08$```,<!(
MA?\/A.@```"`/P`/A-\```!(B7PD".B]\/__28G`2(U``4@]`!````^'\@``
M`$B-5"002(MT)`A)B=&#^`AR#HG!2(G7P>D#\TBE28GY,<FH!'0*BPY!B0FY
M!````*@"=`T/MSP.9D&)/`E(@\$"J`%T"`^V!`Y!B`0)2HU$`O](.<)R'^LB
M9F8N#Q^$``````!F#Q]$``#&``!(@^@!2#G0=`6`."]T[TB)U[XO````2(E4
M)`CHC?#__TB+5"0(2(7`="M(.<)R3DB)U^CF\/__2(N4)!@0``!D2"L4)2@`
M``!U/TB!Q"@0``###Q\`2(N$)!@0``!D2"L$)2@```!U(4B-/40[``!(@<0H
M$```Z:+P__]FD,8``.NM#Q\`,<#KKNBO\/__9F8N#Q^$```````/'T``\P\>
M^E-(@^P09$B+!"4H````2(E$)`@QP`\?@``````QP$B-="0$2(T]!#L``.B-
M]/__2(7`=$!(8U0D!$B+!;R:``!(C0302(M0"$B)$$B%TG3,9F8N#Q^$````
M``"02(M0$$B#P`A(B1!(A=)U\.NN9@\?1```,<!(C70D!$B-/;4Z``#H-?3_
M_TB%P'0X2&-4)`1(BP5DF@``2(T$T$B+4`A(B1!(A=)TS`\?0`!(BU`02(/`
M"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$2(T];3H``.CE\___2(7`=#A(8U0D
M!$B+!12:``!(C0302(M0"$B)$$B%TG3,#Q]``$B+4!!(@\`(2(D02(72=?#K
MMF8/'T0``#'`2(UT)`1(C3TF.@``Z)7S__](A<!T.$AC5"0$2(L%Q)D``$B-
M!-!(BU`(2(D02(72=,P/'T``2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(
MC70D!$B-/=TY``#H1?/__TB%P'0X2&-4)`1(BP5TF0``2(T$T$B+4`A(B1!(
MA=)TS`\?0`!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B-="0$2(T]G3D`
M`.CU\O__2(7`=#A(8U0D!$B+!229``!(C0302(M0"$B)$$B%TG3,#Q]``$B+
M4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT)`1(C3T".0``Z*7R__](A<!T
M.$AC5"0$2(L%U)@``$B-!-!(BU`(2(D02(72=,P/'T``2(M0$$B#P`A(B1!(
MA=)U\.NV9@\?1```,<!(C70D!$B-/0DY``#H5?+__TB%P'0X2&-4)`1(BP6$
MF```2(T$T$B+4`A(B1!(A=)TS`\?0`!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$
M```QP$B-="0$2(T]PS@``.@%\O__2(7`=#A(8U0D!$B+!328``!(C0302(M0
M"$B)$$B%TG3,#Q]``$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(UT)`1(
MC3U].```Z+7Q__](A<!T.$AC5"0$2(L%Y)<``$B-!-!(BU`(2(D02(72=,P/
M'T``2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(C70D!$B-/<LW``#H9?'_
M_TB%P'0X2&-4)`1(BP64EP``2(T$T$B+4`A(B1!(A=)TS`\?0`!(BU`02(/`
M"$B)$$B%TG7PZ[9F#Q]$``!(C70D!$B-/>DW``#H%_'__TB%P'012(G&2(T]
MP3<``#'`Z.'S__\QP$B-="0$2(T]T3<``.CN\/__2(7`=!%(B<9(C3W/-P``
M,<#HN//__S'`2(UT)`1(C3W%-P``Z,7P__](A<!T.TB)QDB-/0XW```QP.B/
M\___2(M$)`AD2"L$)2@```!U14B#Q!!(C36P-P``2(T](#<``#'`6^EE\___
M,<!(C70D!$B-/8(W``#H<O#__TB%P'2^2(G&2(T]$C<``#'`Z#SS___KJ^@U
M[/__#Q]$``#S#Q[Z2(/L&$B-/?`V``!D2(L$)2@```!(B40D"#'`2(UT)`3H
M)_#__TB%P'0R#[80@/HP#Y3`A-(/E,()T(/P`0^VP$B+5"0(9$@K%"4H````
M=1!(@\08PP\?@``````QP.O@Z,?K__\/'X``````\P\>^E!82('LV````$B)
M="0H2(E4)#!(B4PD.$R)1"1`3(E,)$B$P'0W#RE$)%`/*4PD8`\I5"1P#RF<
M)(`````/*:0DD`````\IK"2@````#RFT)+`````/*;PDP````&1(BP0E*```
M`$B)1"08,<!(B?I(C80DX````$B)X4B+/;J5``!(B40D"+X"````2(U$)"#'
M!"0(````QT0D!#````!(B40D$.A"ZO__O_\```#H&.G__P\?A```````0515
M4TR-G"0``/__2('L`!```$B##"0`3#G<=>](@^P0N@(````Q]F1,BR0E*```
M`$R)I"0(``$`08G\Z"_K__](C6C_2(GJ2,'Z/TC!ZC!(C405``^WP$@IT$@I
MQ0^(L````&9F+@\?A```````D#'22(GN1(GGZ//J__](@_C_#X2D````N@@`
M`0!(B>9$B>?HF>C__X/X_P^$?0```$B82(/X!W982(U$!/A(.>!R3DB-%7>4
M``#K#@\?1```2(/H`4@YX'(W2(L(2#D*=>](*>!(`>A(BY0D"``!`&1(*Q0E
M*````'5/2('$$``!`%M=05S#9BX/'X0``````$B![0```0!(@?T``/__#X5<
M____2,?`_____^NZ2(T])S4``#'`Z!7^__](C3T,-0``,<#H!_[__^C"Z?__
M9I#S#Q[Z2(/L".CSZ?__B<?H?.C__TB%P'0#2(L`2(/$",-F9BX/'X0`````
M``\?0`#S#Q[Z05932(G[2(T]UC0``$B#["AD2(L$)2@```!(B40D&#'`2(UT
M)!3H@>W__TB%P'0%@#@`=2](BT0D&&1(*P0E*`````^%F0```$B)WDB#Q"A(
MC3V,-```,<!;05[I*_#__P\?`$B)WTB)!"3H'.C__TB+%"1)B<9(B==(B50D
M".@(Z/__28UT!@)(B?=(B30DZ$?G__](@^P(28G83(T-=S,``/]T)!!(BU0D
M$$B)QTB-#6HT``"^`@```$B)1"00,<#H5>G__UA:2(M$)!AD2"L$)2@```!U
M"4B+-"3I:O___^BEZ/__#Q]$``#S#Q[Z05=(C04),P``059F2`]NR$B-!?@S
M``!!569(#V[02(T%\C,``$%49D@/;MA(C07M,P``569(#V[@,<!32('L>`$`
M`/,/?@5!C@``9$R+/"4H````3(F\)&@!``!)B?](C6PD'$B-/:DR``!(QT0D
M,`````!(QT0D4`````!F#VS!2(GN#RE$)"#S#WX%`XX``$C'A"2(````````
M`&8/;,(/$40D:/,/?@7NC0``9@]LPP\11"1X\P]^!>6-``!F#VS$#RE$)$#H
M[^O__TB%P'0)@#@`#X5Q!```Z/SG__^)Q^B%YO__2(7`#X3L`P``3(LP387V
M#X3@`P``3(GWZ)CF__](C5P``4B)WTF)W>C8Y?__10^V!DB)!"1)B<1%A,!T
M60\?A```````2(G:10^VP$R)YS'`2(T-ZC(``+X"````28/&`>C?Y___23G=
M2(G:10^V!DD/0]5(B=!(*=A(@\`"2#G02`]"PD@ITTF#Q`)(C5P#_D6$P'6O
M2(U<)&A(C3TC,@``ZPV02(L[2(/#"$B%_W0T2(GN,<#H&NO__TF)Q4B%P'3B
M@#@`=-U(B<?HU>O__X7`=-%,B>_HN>;__TB)PTB%P'5#D$R-;"0@ZPUF#Q^$
M``````!)@\4(28M=`$B%VW0E@#L`#X3:`@``2(G?Z)+K__^%P'3>2(G?Z';F
M__](B<-(A<!TSDB)W^B&Y?__3(LD)$F)Q4R)Y^AWY?__18VL!00$``!-8^U,
MB>_HM.3__T%428G83(GJ28G&2(T%[3$``+X"````4$R-#=4P``!,B?<QP$B-
M#<LQ``#HQ.;__TR)][[``0``Z#?G__]?05B#^/]U$NCJY?__1(L(08/Y$0^%
ME@(``$B-M"20````3(GWZ"WF__^)PX7`=%=)BP](BSUMD```38GP,<!(C14Q
M,@``O@(```#HU^/__T4QY`\?0`!(BX0D:`$``&1(*P0E*`````^%"`0``$B!
MQ'@!``!,B>!;74%<05U!7D%?PP\?0`"+A"2H````)0#P```]`$```'661(ND
M)*P```#HP.7__T$YQ'6$BX0DJ````"7_`0``/<`!```/A6W___],B>_HK./_
M_TB)[DB-/;0P``!)B<0QP.AHZ?__2(7`#X1?`@``28L_2(G&Z-3P__](B00D
M2(7`#X1'`@``2(L\).@>Y/__2(G"@_@#?D9(BPPD2)A(B50D"$B--:0P``!(
MC7P!_.@*Y?__A<!U)DB+5"0(@_H$#X3W`@``C4+[2(L,)$B8@#P!+P^$Y`(`
M``\?1```,<!(B>Y(C3V3+P``Z-_H__](A<`/A.8!```/M@"$P`^$VP$``#PP
M#X33`0``2(TUV"\``$B-/60O```QP.B.Z___2(TM:S```.A"X___54R)ZDR-
M#0<O``!038GP2(T-,#```+X"````3(GG,<#H[>3__UA:ZTEF#Q^$``````#H
M&^3__X,X$75(Z`'C__^#PP%(@^P(38GP54R-#;\N``!,B>J^`@```%-(C0WQ
M+P``3(GG4#'`Z*3D__](@\0@OL`!``!,B>?H$^7__X/X_W2N3(GWZ.;B__],
MB>9(C3UD+@``,<#HY>K__TR)Y^A-^O__Z0C^__\/'X0``````#';Z3O]__]F
M#Q^$``````!(C5PD0.L-9@\?A```````2(/#"$B+.TB%_P^$C0```#'`2(GN
MZ+;G__](A<!TX8`X`'3<2(G'Z&3C__])B<9(A<!TS.G7^___28L/2(L][8T`
M`$V)\#'`2(T5<2\``+X"````Z%?A___I>_W__V:02(G'2(D$).BT^?__2(N4
M)&@!``!D2"L4)2@````/A7P!``!(BSPD2('$>`$``%M=05Q!74%>05_I\^+_
M_[\-````0;T-````NPT```#H3N'__TR--5XN``!!N%,```!(B00D28G$Z77[
M__\/'T0``$F+!TB)!"3IK?W__P\?0`!(BSPD,?8QP.A#XO__B<6%P`^$%O[_
M_XG'Z++W__])B<=(A<`/B`/^__\QTDB-</:)[^@)X___2(VT)"H!``"Z!@``
M`(GOZ+7@__](@_@&#X7/````@;PD*@$```!#04,/A<?]__]F@;PD+@$``$A%
M#X6W_?__,=))C7?.2(V<)#`!``")[^BUXO__NB@```!(B=Z)[^AFX/__2(/X
M*`^%@````$B-!0DN``"^`@```$V)\$R)ZL:$)%@!````2(T-P"T``$R-#90L
M``!,B>=0,<!3Z(CB__]97NGS_?__38M_"$V%_P^$%/W__TR)_^C<X/__2(/X
M`P^&`OW__TF-?`?\2(TU:RT``.C1X?__A<!,#T4\)$R)/"3IX?S__^BLX?__
M2(T]3RT``#'`Z-[U__]F9BX/'X0```````\?`/,/'OI!5$B-/38L``!54TB#
M[!!D2(L<)2@```!(B5PD"$B+'6B+``!(C70D!&1(BRL/MH6P````B(6Q````
M,<#H:^7__TB%P'0)@#@Q#X1M`0``Z)CP__]D2(LK2(GON0,```"Z`0```$B-
M-0,M``#HB]___TB)Q4B%P'0H2(M`$&1(BSM(C17I+```2(LPZ)S?__](BT40
M2(LP]D8.0`^%0P$``&1(BSNY`P```+H!````2(TUP"P``.A!W___2(G%2(7`
M=#)(C3U#*P``2(UT)`0QP.C6Y/__2(M5$$B+.DB%P`^$Y@```$B)_F1(BSM(
MB<+H-]___V1(BSNZ`0```$B--7,L``#H4M[__V1(BSM(C15X+```2(G&Z`_?
M__]D2(L#2(UT)`1(C3W7*@``QH"Q`````#'`Z''D__](B07JB@``2(G#2(7`
M=$*^P`$``$B)W^A%X?__C5`!@_H!=@F#^!$/A8H```!(BT0D"&1(*P0E*```
M``^%DP```$B#Q!!;74%<PP\?@`````!(BSVAB@``Z%3W__](B06-B@``2(G#
M2(7`=:-(C3V&+```,<#H)^#__P\?@`````"`>`$`#X22_O__Z83^__^02(L%
M88H``$B+,.@!Z?__Z17___\/'T``9$B+.^B/W___Z:_^__^)P4B+!3F*``!(
MB=I(C3U7+```2(LP,<#HS=___^AXW___#Q^$``````#S#Q[Z4TB)^TB-/3`J
M``!(@^P@9$B+!"4H````2(E$)!@QP$B-="04Z&/C__](A<!T'`^V$(32#Y3`
M@/HP#Y3""-!U"DB%VW0%@#L`=1I(BT0D&&1(*P0E*````'5K2(/$(%O##Q]`
M`$B)W^@`[?__OB\```!(B<=(B40D".A>WO__2(7`2(UX`4@/1'PD".B\WO__
MN@0```!(C35K*@``2(G'Z`C=__^%P'6B2(M$)!AD2"L$)2@```!U#4B#Q"!(
MB=];Z2?D___HHM[__V:005=,C4]X059!54%455-(@>R8`@``9$B+-"4H````
M2(FT)(@"``!(C7<X28G@#Q\`BP9(BPY(@\8(28/`$`_(B<!(B<I)B4#P2(G(
M2,'J($C!Z"A(P>DX)0#_``!("<A(B=%(P>((2,'A&('B``#_`(G)2`G(2`G0
M28E`^$DY\76ON_____]F#V]$)!!(C40D:&8/;UPD(&9(#V[K9@]O5"0P2(V4
M)&@"``!F#VSM9I#S#V\(9@]OXF8/;U#82(/`$&8/[T"(9@_ORF8/[\%F#V_(
M9@]S\`%F#W/1'V8/Z\%F#]O%#RE`"&8/;\-F#V_<2#G"=;M,BP],BU\02(MW
M($B+7QA,B<A,B<I(BV\(2(M,)`A(P>H;2,'@!4@)T`,$)$B-C`N9>8):C90P
MF7F"6DR)V$@QV$@AZ$@QV(TT`DB)ZDB)Z$C!Z`)(P>(>28GR2`G"3(G82<'J
M&T&)T$PQP$PAR$PQV$@!R$B)\4C!X05,"=%,BU0D$$2-)`A,B<A,B<E(P>D"
M2,'@'D^-E!.9>8):38GE2`G(2<'M&T@QPHG!2"'R3#'"3`'238GB2<'B!4T)
MZDR+;"0800'22(GR2,'N`DC!XAY%B=)/C80HF7F"6D@)\DV)U4@QT(G63"'@
M2<'M&T@QR$P!P$V)T$G!X`5-">A,BVPD($$!P$R)X$G![`)(P>`>18G`2HV,
M*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'R2`'*3(G!2,'A!4P)Z4R+;"0H
M`=%,B=))P>H"2,'B'HG)2HVT+IEY@EI,"=))B<U(,=!)P>T;08G23"'`3#'@
M2`'P2(G.2,'F!4P)[DR+;"0P`<9,B<!)P>@"2,'@'HGV3XVD+)EY@EI,"<!)
MB?5(,<))P>T;08G`2"'*3#'23`'B28GT2<'D!4T)[$R+;"0X00'42(G*2,'I
M`DC!XAY%B>1/C90JF7F"6D@)RDV)Y4@QT$G![1N)T4@A\$PQP$P!T$V)XDG!
MX@5-">I,BVPD0$$!PDB)\$C![@)(P>`>18G23XV$*)EY@EI("?!-B=5(,<))
MP>T;B<9,(>)(,<I,`<)-B=!)P>`%30GH3(ML)$A!`=!,B>))P>P"2,'B'D6)
MP$J-C"F9>8):3`GB38G%2#'02<'M&T&)U$PAT$@Q\$@!R$R)P4C!X05,">E,
MBVPD4`'!3(G02<'J`DC!X!Z)R4J-M"Z9>8):3`G028G-2#'"2<'M&T&)PDPA
MPDPQXD@!\DB)SDC!Y@5,">Y,BVPD6`'63(G"2<'H`DC!XAZ)]D^-I"R9>8):
M3`G"28GU2#'02<'M&T&)T$@AR$PQT$P!X$F)]$G!Y`5-">Q,BVPD8$$!Q$B)
MR$C!X!Y(P>D"18GD3XV4*IEY@EI("<A-B>5(,<))P>T;B<%((?),,<),`=)-
MB>))P>(%30GJ3(ML)&A!`=)(B?)(P>X"2,'B'D6)TD^-A"B9>8):2`GR38G5
M2#'02<'M&XG63"'@2#'(3`'`38G02<'@!4T)Z$R+;"1P00'`3(G@2<'L`DC!
MX!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?)(`<I,B<%(P>$%
M3`GI3(ML)'@!T4R)TDC!XAY)P>H"B<E*C;0NF7F"6DP)TDF)S4@QT$G![1M!
MB=),(<!,,>!(`?!(B<Y(P>8%3`GN3(NL)(`````!QDR)P$G!Z`)(P>`>B?9/
MC:0LF7F"6DP)P$F)]4@QPDG![1M!B<!((<I,,=),`>))B?1)P>0%30GL1HTL
M(DB)RDC!Z0),BZ0DB````$C!XAY("<I/C90BF7F"6DV)[$@QT$G![!N)T4@A
M\$PQP$P!T$V)ZDG!X@5-">),BZ0DD````$$!PDB)\$C!X!Y(P>X"18G23XV$
M()EY@EI("?!-B=1(,<))P>P;B<9,(>I(,<I,`<)-B=!)P>`%30G@18G`3`'"
M38GH2<'M`DG!X!Y!B=1-">A,BZPDF````$PQP$PAT$J-C"F9>8):38GE2#'P
M2<'M&T@!R$R)X4C!X05,">F)R4@!R$R)T4G!Z@)(P>$>08G%3`G138G"18G`
M23'*1#'23(N4)*````!*C;06H>O9;DV)ZD@!UDR)ZDG!ZAM(P>(%3`G2B=)(
M`=9,B>)(P>(>2<'L`D&)\DP#A"2H````3`GB28G,B<E(`XPDL````$DQU$0Q
MX$V-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$R)Z$G![0)(P>`>18G@
M3`GH28G5B=)(`Y0DN````$DQQ40Q[DR-K#&AZ]EN3(G!3(G&2,'N&TC!X05(
M"?&)R4D!S4R)T4G!Z@)(P>$>1(GN3`G128G"B<!),<I%,>).C:02H>O9;DB)
M\DF)\DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R$@#A"3`
M````B<E),=!(`XPDR````$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")
MP$D!Q4B)\$C![@)(P>`>18GH2`GP2(G6B=)(`Y0DT````$@QQD0QYDR-I#&A
MZ]EN3(G!3(G&2,'N&TC!X05("?&)R4D!S$R)T4G!Z@)(P>$>1(GF3`G128G"
MB<!(`X0DV````$DQRD4QZDZ-K!*AZ]EN2(GR28GR2<'J&TC!X@5,"=*)TDD!
MU4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!(`XPDX````$4QX$Z-I`"AZ]EN
M3(G038G02<'H&TC!X`5,"<")P$D!Q$B)\$C![@)(P>`>18G@2`GP2(G6B=)(
M`Y0DZ````$@QQD0Q[DR-K#&AZ]EN3(G!3(G&2,'N&TC!X05("?&)R4D!S4R)
MT4G!Z@)(P>$>1(GN3`G128G"B<!(`X0D\````$DQRD4QXDZ-I!*AZ]EN2(GR
M28GR2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(B<E),=!%
M,>A.C:P`H>O9;DR)T$V)T$C!X`5)P>@;2`.,)/@```!,"<")P$D!Q4B)\$C!
M[@)(P>`>18GH2`GP2(G6B=)(`Y0D``$``$@QQD0QYDR-I#&AZ]EN3(G!3(G&
M2,'N&TC!X05("?&)R4D!S$R)T4G!Z@)(P>$>1(GF3`G128G"B<!(`X0D"`$`
M`$DQRD4QZDZ-K!*AZ]EN2(GR28GR2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(
MP>(>18GJ3`G"28G(B<E),=!%,>!.C:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`
M2`.,)!`!``")P$D!Q$B)\$C![@)(P>`>18G@2`GP2(G6B=)(`Y0D&`$``$@Q
MQD0Q[DR-K#&AZ]EN3(G!3(G&2,'N&TC!X05("?&)R4D!S4R)T4G!Z@)(P>$>
M1(GN3`G128G"B<!(`X0D(`$``$DQRD4QXDZ-I!*AZ]EN2(GR28GR2<'J&TC!
MX@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(B<E),=!%,>A.C:P`H>O9
M;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?!(P>`>2,'N`D6)Z$@#C"0H`0``
M2`GP2(G6B=)(`Y0D,`$``$@QQD0QYDV)Q$B-C#&AZ]EN3(G&2<'L&TC!Y@5,
M">9-B=1)P>H"2<'D'HGV30G428G"2`'QB<!-,>*)SD@#A"0X`0``13'J28GU
M3HV4$J'KV6Y(B?))P>T;2,'B!4P)ZD$!TDR)PDG!Z`)(P>(>18G23`G"38G@
M18GD23'028G608G51#'!38G02(V,"*'KV6Y,B=!)P>@;2,'@!4P)P$2-!`%(
MB?%(P>X"N-R\&X](P>$>2`GQ20G.B<Y((?)-(=9)"=9(BY0D0`$``$@!PDP!
MXDV)Q$P!\DV)QDG!Y`5)P>X;30GT00'43(G22<'J`DC!XAY%B>1,"=)("=%)
MB=9!B=))(?9,(<%,"?%,B[0D2`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%
M30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),B[0D
M4`$``$D!QDP!]DV)[D@!\DR)[DG![AM(P>8%3`GV`=9,B>))P>P"2,'B'HGV
M3`GB2`G128G608G432'&3"'I3`GQ3(NT)%@!``!)`<9-`?))B?9,`=%)B?))
MP>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-20G.22'V3"'J
M3`GR3(NT)&`!``!)`<9-`?!-B=9,`<)-B=!)P>`%2<'N&TT)\$$!T$B)\DC!
M[@)(P>(>18G`2`GR2`G128G6B=9-(>Y,(=%,"?%,B[0D:`$``$D!QDT!]$V)
MQDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%B>1,"=%!B<I)
M"<Y-(<9,(=),"?),B[0D<`$``$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU
M00'53(G"2,'B'DG!Z`)%B>U,"<)("=%)B=9!B=!-(=9,(>%,"?%,B[0D>`$`
M`$D!QDP!]DV)[D@!\4R)[DG![AM(P>8%3`GV28G6`<Y,B>%)P>P"2,'A'HGV
M3`GA08G,20G.32'N3"'B3`GR3(NT)(`!``!)`<9-`?))B?9,`=))B?))P>X;
M2<'B!4T)\D$!TDR)ZDG![0)(P>(>18G23`GJ2`G128G608G52"'Q32'F3`GQ
M3(NT)(@!``!)`<9-`?!-B=9,`<%-B=!)P>X;2<'@!4T)\$F)UD$!R$B)\4C!
M[@)(P>$>18G`2`GQB<Y)"<Y-(=9((?),"?),B[0DD`$``$D!QDT!]$V)QDP!
MXDV)Q$G![AM)P>0%30GT00'43(G22<'J`DC!XAY%B>1,"=)("=%)B=9!B=))
M(?9,(<%,"?%,B[0DF`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G6
M00'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),B[0DH`$``$D!
MQDP!]DV)[D@!\DR)[DG![AM(P>8%3`GV`=9,B>))P>P"2,'B'HGV3`GB2`G1
M28G608G432'&3"'I3`GQ3(NT)*@!``!)`<9-`?))B?9,`=%)B?))P>X;2<'B
M!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-20G.22'V3"'J3`GR3(NT
M)+`!``!)`<9-`?!-B=9,`<)-B=!)P>X;2<'@!4T)\$$!T$B)\DC![@)(P>(>
M18G`2`GR2`G128G6B=9-(>Y,(=%,"?%,B[0DN`$``$D!QDT!]$V)QDP!X4V)
MQ$G![AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%B>1,"=%)"<Y!B<I-(<9,
M(=),"?),B[0DP`$``$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU00'53(G"
M2<'H`DC!XAY%B>U,"<)("=%)B=!!B==-(=!,(>%,"<%,BX0DR`$``$D!P$P!
MQDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$,4R)YDG![`)(B=%(P>8>3`GF08GT
M2`GQ3"'I3"'B2`G*2(N,)-`!``!(`<%,`=%-B<)(`X0DV`$``$@!RDR)P4G!
MZAM(P>$%3`G1B<E(`<I,B>E)P>T"2,'A'D&)TDP)Z4@)SDF)S4&)SDPAQDTA
MY4D)]4J--#A,B=!,B[PD^`$``$P![DV)U4C!X`5)P>T;3`GHB<!(`<9,B<!)
MP>@"2,'@'D&)]4D)P+C6P6+*3#'!,=%(BY0DX`$``$@!PDP!XDV)[$@!RDR)
MZ4G![!M(P>$%3`GA38G4B<E)P>0>2`'*2<'J`DD!QTT)XDV)Q(G118G`33'4
M1#'F3(ND).@!``!)`<1-`?1)B<Y,`>9)B<Q)P>X;2<'D!4T)]$V)[DG![0))
MP>8>18GD30GU3(NT)/`!``!,`>9!B?1)`<9-`?!-B=9-,>Y$,?)-B>9)`=!,
MB>))P>X;2,'B!4P)\HG220'02(G*2,'I`DC!XAY%B<9("<I$B=%-B>I),=),
M`?E,B[PD``(``$0QUDV)\D@!SDR)\4C!X05)P>H;20''3`G1B<E(`<Y,B>%)
MP>P"2,'A'D&)\DD)S$2)Z4F)U8G233'E3`'Y3(N\)!`"``!%,>A-B=5)`<A,
MB=%)P>T;20''2,'A!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D"`(`
M`$D!QDP!\DV)YDDQSD0Q]DV)[D@!UDR)ZDG![AM(P>(%3`GRB=)(`=9,B=))
MP>H"2,'B'D&)]DD)TD2)XDF)S(G)3`'Z33'43(N\)"`"``!%,>!-B?1)`=!,
MB?))P>P;20''2,'B!4P)XHG220'03(GJ2<'M`DC!XAY%B<1,">I,BZPD&`(`
M`$D!Q4P!Z4V)U4DQU40Q[DV)Y4@!SDR)X4G![1M(P>$%3`GIB<E(`<Y,B?%)
MP>X"2,'A'D&)]4D)SD2)T4F)THG233'R3`'Y3(N\)#`"``!%,=!-B>I)`<A,
MB>E)P>H;2,'A!4P)T8G)20'(3(GA2,'A'DG![`)%B<))`<=,">%,BZ0D*`(`
M`$D!Q$P!XDV)]$DQS$0QYDV)U$@!UDR)TDG![!M(P>(%3`GBB=)(`=9,B>I)
MP>T"2,'B'D&)]$D)U42)\DF)SHG)33'N3`'Z3(N\)$`"``!%,?!-B>9)`=!,
MB>))P>X;2,'B!4P)\HG220'03(G22<'J`DC!XAY%B<9,"=),BY0D.`(``$D!
MPDP!T4V)ZDDQTD0QUDV)\D@!SDR)\4C!X05)P>H;20''3`G1B<E(`<Y,B>%)
MP>P"2,'A'D&)\DD)S$2)Z4F)U8G233'E3`'Y3(N\)&`"``!%,>A-B=5)`<A,
MB=%)P>T;2,'A!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D2`(``$D!
MQDP!\DV)YD6)Y$DQSD0Q]DV)[D@!UDR)ZDG![AM(P>(%3`GRB=)(`=9,B=))
MP>H"2,'B'D&)]DD)TDB+E"10`@``2`'"20'42(G*B<E,,=))`<=$,<)-B?!)
M`=1,B?))P>@;2,'B!4P)PHG220'43(GJ2<'M`DC!XAY%B>!,">I,BZPD6`(`
M`$D!Q4P!Z4V)U4DQU40Q[DV)Q4@!SDR)P4G![1M(P>$%3`GIB<E(`<Y,B?%)
MP>X"2,'A'D&)]4D)SD2)T4F)THG233'R3`'Y3(N\)'`"``!%,>)-B>Q,`=%-
MB>I)P>P;2<'B!4T)XDV)Q$6)TDG!Y!Y,`=%)P>@"20''30G@3(ND)&@"``!!
MB<I)`<1(`X0D>`(``$P!XDV)]$P!R$TQQ$0QYDV)U$@!UDR)TDG![!M(P>(%
M3`GB38GL2<'M`DG!Y!Z)TDT)Y46)]$V)QD@!UDTQ[HGR30'\18G`1#'Q28G6
M3`'`38GH3`'A28G42<'N&TG!Y`5-"?1$`>%-B=1)P>H"2<'D'HG)30GB33'0
M1#'&28G(2`'P2(G.2,'F!4G!Z!L!Z4$!VDP)QD0#;R!(B4\(`?!,B5<82(D'
M2(G02,'J`DC!X!Y,B6\@2`G01`'82(E'$$B+A"2(`@``9$@K!"4H````=1)(
M@<28`@``6UU!7$%=05Y!7\/H1LC__V8/'T0``/,/'OI(@^P(OX````#H?L;_
M_V8/;P7&4@``2,=`,``````/$0!F#V\%PU(``,=`>``````/$4`09@]O!<!2
M```/$4`@2(/$",,/'X``````\P\>^D%72&/"28G_059!54F)]4%428G$55-(
M@^P82(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P2&-'>(7`#X45
M`0``08/\/WYS1(GE3(GKP>T&C47_2,'E!HE$)`1,`>U(B40D"`\?`/,/;P-,
MB?](@\-`00\11SCS#V]#T$$/$4=(\P]O0^!!#Q%'6/,/;T/P00\11VCHK>C_
M_T@YZW7(BT0D!/?8P>`&18UD!,!(BT0D"$C!X`9-C6P%0$ECQ$B#^`AR:TF+
M50!)C7=`28U/.$B#YOA)B5<X28M4!?A(*?%)*<U)B50',$@!R$B#X/A(@_@(
M<B)(@^#X,=))BTP5`$B)#!9(@\((2#G"<NYF+@\?A```````18EG>$B#Q!A;
M74%<05U!7D%?PP\?1```J`1U9TB%P'3?00^V50!!B%<XJ`)TTD$/MU0%_F9!
MB50'-NO$#Q]``+U`````2(U\!SA,B>XIQ40YY4$/3^Q(8]U(B=KH7\?__T&+
M1W@!Z$&)1WB#^$!UE$R)_T$I[$D!W>BRY___Z:C^__]!BU4`08E7.$&+5`7\
M08E4!S3I9O___V8/'T0``/,/'OI52(GU4TB)^TB#[!A,BT8H2(MV,$R)P$C!
MZ`.#X#^-4`'&1`4X@$ACPDB-3`4X@_HX#XZ-`0``N$`````IT'0/,=*)UX/"
M`<8$.0`YPG+S2(GO2(ET)`A,B00DZ"SG__]F#^_`3(L$)$C'16@`````2(MT
M)`@/$44X#Q%%2`\115A(B?)!#[;`38G"38G!2,'J&$C!X`A(B?%)P>H028G3
M3(G"2<'I&`^V_DB)\DC!Z1!("?A!#[;Z#[;)2,'@"$@)^$$/MOE(P>`(2`GX
M0`^V_@^V]D$/MM-(P>`(2`GX2(GO2,'@"$@)\$C!X`A("<A(P>`(2`G02(E%
M<.B,YO__2(M%`$B)[TC!Z!B(`TB+10!(P>@0B$,!2(M%`(AC`DB+10"(0P-(
MBT4(2,'H&(A#!$B+10A(P>@0B$,%2(M%"(AC!DB+10B(0P=(BT402,'H&(A#
M"$B+11!(P>@0B$,)2(M%$(AC"DB+11"(0PM(BT482,'H&(A##$B+11A(P>@0
MB$,-2(M%&(AC#DB+11B(0P](BT4@2,'H&(A#$$B+12!(P>@0B$,12(M%((AC
M$DB+12"(0Q-(@\086UWI6\/__P\?`+@X````*="#^`AS+*@$=7B%P`^$I?[_
M_\8!`*@"#X2:_O__,=)FB50!_NF._O__9@\?A```````B<)(QP$`````2,=$
M$?@`````2(U1"$B#XOA(*=$!R(/@^(/X"`^"6O[__X/@^#')B<^#P0A(QP0Z
M`````#G!<N_I/_[__V8N#Q^$``````#'`0````#'1`'\`````.DB_O__9BX/
M'X0```````\?`/,/'OI(BPW=;0``Z=#!___S#Q[Z2(/L"$B#Q`C#````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%53
M15(`55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@!S:&]R
M="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V,P`M
M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````
M``````$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````
M``````````$;`SL$`0``'P```'!O__\X`0``X'+__V`!``#P<O__>`$``%!V
M___0!0``8'C__R`!``!0>?__D`$``"!Z___<`0``L'K__P`"```P?/__-`(`
M`(!^__]X`@``8'___[`"``"P?___S`(``.!____@`@``P(#__Q0#``#0@/__
M*`,```"#__^,`P``,(/__Z@#``"0A/__T`,```")___T`P``<(G__Q`$```P
MBO__+`0``'"+__]L!```H(O__X0$``"0C/__O`0``*"3__]L!0``P)7__Z`%
M``"0EO__``8``/"L__]0!@``0*W__V@&````K___M`8``'"Q___@!@``````
M`!0``````````7I2``%X$`$;#`<(D`$``!0````<````.'?__R8`````1`<0
M`````"0````T````,&[__W`#````#A!&#AA*#PMW"(``/QHY*C,D(@`````4
M````7````'AQ__\0```````````````4````=````'!Q__]@`P``````````
M``!(````C````+AW___%`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`(````-@````\>/__
M@P````!!#A"#`D<.L`$"=`H.$$$."$$+,````/P```"H>/__=`$```!"#A".
M`D$.&(8#00X@@P1'#M`!?@H.($$.&$$.$$(."$,+`$`````P`0``]'G__TD"
M````0@X0C@)$#AB-`T(.((P$00XHA@5!#C"#!D0.4`,;`0H.,$$.*$$.($(.
M&$(.$$(."$<+-````'0!````?/__X`````!"#A",`D$.&(8#00X@@P1'#J`@
M20[`(`)U"@X@00X800X00@X(00L8````K`$``*A\__]/`````$4.$(,";0X(
M````$````,@!``#<?/__*0`````````P````W`$``/A\___>`````$4.$(8"
M00X8@P-'#I@@3`Z80$D.T$`"L0H.&$0.$$$."$$+$````!`"``"D??__"0``
M``````!@````)`(``*!]__\B`@```$8.$(\"0@X8C@-"#B"-!$(.*(P%00XP
MA@9!#CB#!T<.N"!,#O`A`G$*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P*Y#O@A
M3@Z`(F4.^"%!#O`A````&````(@"``!L?___(P````!%#A"#`ED."````"0`
M``"D`@``@'___U$!````2PZ(($D.L"`#``$*#@A$"V$*#@A'"P`@````S`(`
M`+B`__]K!````$4.$(,"1`X@`QP$"@X040X(10L8````\`(```2%__]I````
M`$@.(`)0"@X(2`L`&`````P#``!8A?__N`````!%#A!!#@A'#N`!`#P````H
M`P``_(7__SX!````0@X0C`)!#AB&`T$.((,$2`P+H(`$40T'1`ZP@`0"T`H.
M($$.&$$.$$(."$L+```4````:`,``/R&__\A`````$@.$%@."``T````@`,`
M`!2'___K`````$8.$(X"00X8@P-.#D!_"@X82@X00@X(2`MU#DA.#E!A#DA!
M#D```*P```"X`P``S(?__P('````1@X0CP))#AB.`TX.((T$3@XHC`5-#C"&
M!D@..(,'1PZP`P/W`0ZX`U8.P`-F#K@#0@ZP`P)R"@XX1`XP00XH0@X@0@X8
M0@X00@X(10L#'P$.N`-+#L`#6@ZX`T$.L`-A#K@#1`[``U`.R`-+#M`#2PZP
M`P+N"@XX00XP00XH0@X@0@X80@X00@X(10L#$P$.N`-##L`#1@ZX`T$.L`,`
M,````&@$```LCO__&`(```!&#A",`D@.&(8#00X@@P1$#C`#<0$*#B!!#AA!
M#A!"#@A("RP```"<!```&)#__\X`````10X0@P).#C`"3PH.$$$."$4+`E@*
M#A!$#@A%"P```"P```#,!```>'#__PT"````10X0A@)!#AB#`T0.4`-H`0H.
M&$,.$$$."$$+`````$P```#\!```B)#__UH6````0@X0CP)&#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'1P[0!0,U%@H..$$.,$$.*$(.($(.&$(.$$(."$$+
M````%````$P%``"8IO__20````!(#A`"0`X(2````&0%``#0IO__N@$```!&
M#A"/`D@.&(X#0@X@C01%#BB,!40.,(8&00XX@P=$#E`#"@$*#CA!#C!!#BA"
M#B!"#AA"#A!"#@A&"R@```"P!0``1*C__V,"````10X0A@)$#AB#`T<.,`.N
M`0H.&$$.$$$."$@+$````-P%``"(JO__$```````````````!````!`````!
M````1TY5```````#`````@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/`I````````L"D```````!.<0```````.EP````````!G$```````!?
M<0````````$`````````\0(````````!``````````$#````````#```````
M````(`````````T`````````,&(````````9`````````,#+````````&P``
M```````(`````````!H`````````R,L````````<``````````@`````````
M]?[_;P````#@`P````````4`````````D`H````````&`````````#`$````
M````"@````````!:`P````````L`````````&``````````5````````````
M`````````P````````#PS0````````(`````````$`4````````4````````
M``<`````````%P````````#8$`````````<`````````^`X````````(````
M`````.`!````````"0`````````8`````````!X`````````"`````````#[
M__]O``````$```@`````_O__;P````!X#@```````/___V\``````0``````
M``#P__]O`````.H-````````^?__;P`````(````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````\,L`````````````````````````
M````,"````````!`(````````%`@````````8"````````!P(````````(`@
M````````D"````````"@(````````+`@````````P"````````#0(```````
M`.`@````````\"``````````(0```````!`A````````("$````````P(0``
M`````$`A````````4"$```````!@(0```````'`A````````@"$```````"0
M(0```````*`A````````L"$```````#`(0```````-`A````````X"$`````
M``#P(0`````````B````````$"(````````@(@```````#`B````````0"(`
M``````!0(@```````&`B````````<"(```````"`(@```````)`B````````
MH"(```````"P(@```````,`B````````T"(```````#@(@```````/`B````
M`````",````````0(P```````"`C````````,",```````!`(P```````%`C
M````````8",```````!P(P```````(`C````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T`````````I005(N<&T*``````````#X
M<@```````$=#0SH@*$UA9V5I82`Q-2XQ+C`M,2YM9V$Q,"D@,34N,2XP```N
M<VAS=')T86(`+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+F=N=2YB=6EL9"UI
M9``N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S
M:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`
M+G!L="YG;W0`+G!L="YS96,`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A
M;65?:&1R`"YE:%]F<F%M90`N;F]T92Y!0DDM=&%G`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M``````````````````````````````````````````L````'`````@``````
M``!0`P```````%`#````````4`````````````````````@`````````````
M```````>````!P````(`````````H`,```````"@`P```````"0`````````
M```````````$````````````````````,0````$````"`````````,0#````
M````Q`,````````<`````````````````````0```````````````````#D`
M``#V__]O`@````````#@`P```````.`#````````3``````````%````````
M``@```````````````````!#````"P````(`````````,`0````````P!```
M`````&`&````````!@````$````(`````````!@`````````2P````,````"
M`````````)`*````````D`H```````!:`P```````````````````0``````
M`````````````%,```#___]O`@````````#J#0```````.H-````````B```
M```````%``````````(``````````@````````!@````_O__;P(`````````
M>`X```````!X#@```````(``````````!@````$````(````````````````
M````;P````0````"`````````/@.````````^`X```````#@`0````````4`
M````````"``````````8`````````'D````$````0@````````#8$```````
M`-@0````````$`4````````%````&0````@`````````&`````````"#````
M`0````8``````````"``````````(````````!L````````````````````$
M````````````````````?@````$````&`````````"`@````````("``````
M``!P`P``````````````````$``````````0`````````(D````!````!@``
M``````"0(P```````)`C````````$````````````````````!``````````
M$`````````"2`````0````8`````````H",```````"@(P```````&`#````
M```````````````0`````````!``````````FP````$````&```````````G
M`````````"<````````P.P``````````````````(```````````````````
M`*$````!````!@`````````P8@```````#!B````````#0``````````````
M``````0```````````````````"G`````0````(``````````'``````````
M<````````+!````````````````````0````````````````````KP````$`
M```"`````````+"P````````L+`````````$`0``````````````````!```
M`````````````````+T````!`````@````````"XL0```````+BQ````````
M\`4```````````````````@```````````````````#'````!P````(`````
M````J+<```````"HMP```````"`````````````````````$````````````
M````````U0````X````#`````````,#+````````P+L````````(````````
M````````````"``````````(`````````.$````/`````P````````#(RP``
M`````,B[````````"`````````````````````@`````````"`````````#M
M`````0````,`````````T,L```````#0NP```````"``````````````````
M```(````````````````````^@````8````#`````````/#+````````\+L`
M`````````@````````8`````````"``````````0`````````(T````!````
M`P````````#PS0```````/"]````````$`(```````````````````@`````
M````"``````````#`0```0````,``````````-``````````P````````"@`
M```````````````````(````````````````````"0$```@````#````````
M`$#0````````*,````````!8````````````````````(```````````````
M``````X!```!````,````````````````````"C`````````)```````````
M``````````$``````````0`````````!`````P``````````````````````
J``!,P````````!<!```````````````````!````````````````````
